tkImg: Manipulate image resources for Tcl/Tk GUIs
Description
These functions read image files on disk and create Tk image resources.Usage
tkImgAdd(file, type = "gif", update = FALSE)
tkImgDel(image)
tkImgRead(dir, type = "gif")
Arguments
file
image file from where to download the resource.
type
type of image. Currently, only 'gif' is supported.
update
do we update an already loaded image resource, or not?
dir
the directory that contains one or more image files to read.
Value
tkImgAdd() returns the handle to the newly created image invisibly.
tkImgDel() returns invisibly TRUE if the resource is found and
deleted, FALSE otherwise.
tkImgRead() returns invisibly the list of image files that are imported
as resources.
concept
GUI image resources in TclDetails
These functions should not be called directly, but by means of
ImgAdd(), ImgDel() or ImgRead().