tkImgAdd(file, type = "gif", update = FALSE)
tkImgDel(image)
tkImgRead(dir, type = "gif")tkImgAdd() returns the handle to the newly created image invisibly.
tkImgDel() returns invisibly TRUE if the resource is found and
deleted, FALSE otherwise.
tkImgRead() returns invisibly the list of image files that are imported
as resources.ImgAdd(), ImgDel() or ImgRead().ImgAdd, ImgDel, ImgRead